==> grantlee5_5.1.0.orig.tar.gz: grantlee-5.1.0/templates/defaultfilters/datetime.h <==
/*
  This file is part of the Grantlee template system.

  Copyright (c) 2009,2010 Stephen Kelly <steveire@gmail.com>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either version
  2.1 of the Licence, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef DATETIMEFILTERS_H
#define DATETIMEFILTERS_H

#include "filter.h"

using namespace Grantlee;

class DateFilter : public Filter
{
public:
  QVariant doFilter(const QVariant &input,
                    const QVariant &argument = QVariant(),
                    bool autoescape = false) const override;
};

class TimeFilter : public Filter
{
public:
  QVariant doFilter(const QVariant &input,
                    const QVariant &argument = QVariant(),
                    bool autoescape = false) const override;
};

class TimeSinceFilter : public Filter
{
public:
  QVariant doFilter(const QVariant &input,
                    const QVariant &argument = QVariant(),
                    bool autoescape = false) const override;
};

class TimeUntilFilter : public Filter
{
public:
  QVariant doFilter(const QVariant &input,
                    const QVariant &argument = QVariant(),
                    bool autoescape = false) const override;
};

#endif

==> grantlee5_5.3.1.orig.tar.gz: grantlee-5.3.1/templates/defaultfilters/datetime.h <==
/*
  This file is part of the Grantlee template system.

  Copyright (c) 2009,2010 Stephen Kelly <steveire@gmail.com>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either version
  2.1 of the Licence, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef DATETIMEFILTERS_H
#define DATETIMEFILTERS_H

#include "filter.h"

using namespace Grantlee;

class DateFilter : public Filter
{
public:
  QVariant doFilter(const QVariant &input, const QVariant &argument = {},
                    bool autoescape = {}) const override;
};

class TimeFilter : public Filter
{
public:
  QVariant doFilter(const QVariant &input, const QVariant &argument = {},
                    bool autoescape = {}) const override;
};

class TimeSinceFilter : public Filter
{
public:
  QVariant doFilter(const QVariant &input, const QVariant &argument = {},
                    bool autoescape = {}) const override;
};

class TimeUntilFilter : public Filter
{
public:
  QVariant doFilter(const QVariant &input, const QVariant &argument = {},
                    bool autoescape = {}) const override;
};

#endif
